@@ -17,7 +17,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 #{{{sub new
 
@@ -29,12 +29,12 @@ sub new {
     my $user = {
         BaseURL  => $$authn->{'BaseURL'},
         Authn    => $authn,
-        Message  => "",
+        Message  => q{},
         Response => \$response,
         Verbose  => $verbose,
         Log      => $log
     };
-    bless( $user, $class );
+    bless $user, $class;
     return $user;
 }
 
@@ -61,7 +61,7 @@ sub add {
     );
     my $success = Apache::Sling::UserUtil::add_eval($res);
     my $message = "User: \"$act_on_user\" ";
-    $message .= ( $success ? "added!" : "was not added!" );
+    $message .= ( $success ? 'added!' : 'was not added!' );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -75,7 +75,7 @@ sub add_from_file {
     my $count             = 0;
     my $number_of_columns = 0;
     my @column_headings;
-    if ( open my ($input), "<", $file ) {
+    if ( open my ($input), '<', $file ) {
         while (<$input>) {
             if ( $count++ == 0 ) {
 
@@ -84,22 +84,22 @@ sub add_from_file {
                     @column_headings = $csv->fields();
 
                     # First field must be site:
-                    if ( $column_headings[0] !~ /^[Uu][Ss][Ee][Rr]$/x ) {
+                    if ( $column_headings[0] !~ /^[Uu][Ss][Ee][Rr]$/msx ) {
                         croak
-"First CSV column must be the user ID, column heading must be \"user\". Found: \""
+'First CSV column must be the user ID, column heading must be "user". Found: "'
                           . $column_headings[0] . "\".\n";
                     }
                     if ( $column_headings[1] !~
-                        /^[Pp][Aa][Ss][Ss][Ww][Oo][Rr][Dd]$/x )
+                        /^[Pp][Aa][Ss][Ss][Ww][Oo][Rr][Dd]$/msx )
                     {
                         croak
-"Second CSV column must be the user password, column heading must be \"password\". Found: \""
+'Second CSV column must be the user password, column heading must be "password". Found: "'
                           . $column_headings[0] . "\".\n";
                     }
                     $number_of_columns = @column_headings;
                 }
                 else {
-                    croak "CSV broken, failed to parse line: "
+                    croak 'CSV broken, failed to parse line: '
                       . $csv->error_input;
                 }
             }
@@ -117,19 +117,21 @@ sub add_from_file {
                     my $id       = $columns[0];
                     my $password = $columns[1];
                     for ( my $i = 2 ; $i < $number_of_columns ; $i++ ) {
-                        my $value = $column_headings[$i] . "=" . $columns[$i];
-                        push( @properties, $value );
+                        my $heading = $column_headings[$i];
+                        my $data    = $columns[$i];
+                        my $value   = "$heading = $data";
+                        push @properties, $value;
                     }
                     $user->add( $id, $password, \@properties );
                     Apache::Sling::Print::print_result($user);
                 }
                 else {
-                    croak "CSV broken, failed to parse line: "
+                    croak q{CSV broken, failed to parse line: }
                       . $csv->error_input;
                 }
             }
         }
-        close($input);
+        close $input or croak q{Problem closing input};
     }
     return 1;
 }
@@ -148,7 +150,7 @@ sub change_password {
     );
     my $success = Apache::Sling::UserUtil::change_password_eval($res);
     my $message = "User: \"$act_on_user\" ";
-    $message .= ( $success ? "password changed!" : "password not changed!" );
+    $message .= ( $success ? 'password changed!' : 'password not changed!' );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -166,7 +168,7 @@ sub del {
     );
     my $success = Apache::Sling::UserUtil::delete_eval($res);
     my $message = "User: \"$act_on_user\" ";
-    $message .= ( $success ? "deleted!" : "was not deleted!" );
+    $message .= ( $success ? 'deleted!' : 'was not deleted!' );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -184,7 +186,7 @@ sub check_exists {
     );
     my $success = Apache::Sling::UserUtil::exists_eval($res);
     my $message = "User \"$act_on_user\" ";
-    $message .= ( $success ? "exists!" : "does not exist!" );
+    $message .= ( $success ? 'exists!' : 'does not exist!' );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -199,9 +201,9 @@ sub me {
         Apache::Sling::UserUtil::me_setup( $user->{'BaseURL'} ) );
     my $success = Apache::Sling::UserUtil::me_eval($res);
     my $message = (
-          $success
-        ? $$res->content
-        : "Problem fetching details for current user"
+        $success
+        ? ${$res}->content
+        : 'Problem fetching details for current user'
     );
     $user->set_results( "$message", $res );
     return $success;
@@ -217,9 +219,9 @@ sub sites {
         Apache::Sling::UserUtil::sites_setup( $user->{'BaseURL'} ) );
     my $success = Apache::Sling::UserUtil::sites_eval($res);
     my $message = (
-          $success
-        ? $$res->content
-        : "Problem fetching details for current user"
+        $success
+        ? ${$res}->content
+        : 'Problem fetching details for current user'
     );
     $user->set_results( "$message", $res );
     return $success;
@@ -238,7 +240,7 @@ sub update {
     );
     my $success = Apache::Sling::UserUtil::update_eval($res);
     my $message = "User: \"$act_on_user\" ";
-    $message .= ( $success ? "updated!" : "was not updated!" );
+    $message .= ( $success ? 'updated!' : 'was not updated!' );
     $user->set_results( "$message", $res );
     return $success;
 }
@@ -255,8 +257,11 @@ sub view {
         )
     );
     my $success = Apache::Sling::UserUtil::exists_eval($res);
-    my $message =
-      ( $success ? $$res->content : "Problem viewing user: \"$act_on_user\"" );
+    my $message = (
+        $success
+        ? ${$res}->content
+        : "Problem viewing user: \"$act_on_user\""
+    );
     $user->set_results( "$message", $res );
     return $success;
 }
